@@ -134,9 +134,9 @@ namespace Rstats {
     NV pow(NV, NV);
     NV pow(IV, IV);
 
-    std::complex<NV> reminder(std::complex<NV>, std::complex<NV>);
-    NV reminder(NV, NV);
-    IV reminder(IV, IV);
+    std::complex<NV> remainder(std::complex<NV>, std::complex<NV>);
+    NV remainder(NV, NV);
+    IV remainder(IV, IV);
 
     NV Re(std::complex<NV>);
     NV Re(NV);
@@ -757,7 +757,7 @@ namespace Rstats {
     Rstats::Vector* add(Rstats::Vector*, Rstats::Vector*);
     Rstats::Vector* subtract(Rstats::Vector*, Rstats::Vector*);
     Rstats::Vector* multiply(Rstats::Vector*, Rstats::Vector*);
-    Rstats::Vector* reminder(Rstats::Vector*, Rstats::Vector*);
+    Rstats::Vector* remainder(Rstats::Vector*, Rstats::Vector*);
 
     Rstats::Vector* divide(Rstats::Vector*, Rstats::Vector*);
     Rstats::Vector* atan2(Rstats::Vector*, Rstats::Vector*);
@@ -852,6 +852,55 @@ namespace Rstats {
     SV* names(SV*, SV*, SV*);
     SV* names(SV*, SV*);
     
+    SV* tanh(SV*, SV*);
+    SV* Mod(SV*, SV*);
+    SV* Arg(SV*, SV*);
+    SV* Conj(SV*, SV*);
+    SV* Re(SV*, SV*);
+    SV* Im(SV*, SV*);
+    SV* abs(SV*, SV*);
+    SV* acos(SV*, SV*);
+    SV* acosh(SV*, SV*);
+    SV* asin(SV*, SV*);
+    SV* asinh(SV*, SV*);
+    SV* atan(SV*, SV*);
+    SV* atanh(SV*, SV*);
+    SV* cos(SV*, SV*);
+    SV* cosh(SV*, SV*);
+    SV* cumsum(SV*, SV*);
+    SV* cumprod(SV*, SV*);
+    SV* exp(SV*, SV*);
+    SV* expm1(SV*, SV*);
+    SV* log(SV*, SV*);
+    SV* logb(SV*, SV*);
+    SV* log2(SV*, SV*);
+    SV* log10(SV*, SV*);
+    SV* prod(SV*, SV*);
+    SV* sinh(SV*, SV*);
+    SV* sqrt(SV*, SV*);
+    SV* tan(SV*, SV*);
+    SV* sin(SV*, SV*);
+    SV* sum(SV*, SV*);
+    SV* negation(SV*, SV*);
+    SV* operate_unary(SV*, Rstats::Vector* (*func)(Rstats::Vector*), SV*);
+    SV* operate_binary(SV*, Rstats::Vector* (*func)(Rstats::Vector*, Rstats::Vector*), SV*, SV*);
+    SV* upgrade_type(SV*, SV*);
+
+    SV* atan2(SV*, SV*, SV*);
+    SV* add(SV*, SV*, SV*);
+    SV* subtract(SV*, SV*, SV*);
+    SV* multiply(SV*, SV*, SV*);
+    SV* divide(SV*, SV*, SV*);
+    SV* remainder(SV*, SV*, SV*);
+    SV* pow(SV*, SV*, SV*);
+    SV* less_than(SV*, SV*, SV*);
+    SV* less_than_or_equal(SV*, SV*, SV*);
+    SV* more_than(SV*, SV*, SV*);
+    SV* more_than_or_equal(SV*, SV*, SV*);
+    SV* equal(SV*, SV*, SV*);
+    SV* not_equal(SV*, SV*, SV*);
+    SV* And(SV*, SV*, SV*);
+    SV* Or(SV*, SV*, SV*);
   }
 }
 
