@@ -4,6 +4,346 @@
 namespace Rstats {
   namespace Func {
 
+    SV* operate_binary(SV* sv_r, Rstats::Vector* (*func)(Rstats::Vector*, Rstats::Vector*), SV* sv_x1, SV* sv_x2) {
+      
+      sv_x1 = Rstats::Func::to_c(sv_r, sv_x1);
+      sv_x2 = Rstats::Func::to_c(sv_r, sv_x2);
+
+      
+      // Upgrade mode if type is different
+      SV* upgrade_type_args = Rstats::pl_new_av_ref();
+      Rstats::pl_av_push(upgrade_type_args, sv_x1);
+      Rstats::pl_av_push(upgrade_type_args, sv_x2);
+      
+      SV* upgrade_type_result = Rstats::Func::upgrade_type(sv_r, upgrade_type_args);
+      
+      if (Rstats::VectorFunc::get_type(Rstats::Func::get_vector(sv_r, sv_x1))
+        != Rstats::VectorFunc::get_type(Rstats::Func::get_vector(sv_r, sv_x2)))
+      {
+        sv_x1 = Rstats::pl_av_fetch(upgrade_type_result, 0);
+        sv_x2 = Rstats::pl_av_fetch(upgrade_type_result, 1);
+      }
+      
+      // Upgrade length if length is defferent
+      SV* sv_x1_length = Rstats::Func::length_value(sv_r, sv_x1);
+      SV* sv_x2_length = Rstats::Func::length_value(sv_r, sv_x2);
+      SV* sv_length;
+      if (SvIV(sv_x1_length) > SvIV(sv_x2_length)) {
+        sv_x2 = Rstats::Func::array(sv_r, sv_x2, Rstats::Func::c(sv_r, sv_x1_length));
+      }
+      else if (SvIV(sv_x1_length) < SvIV(sv_x2_length)) {
+        sv_x1 = Rstats::Func::array(sv_r, sv_x1, Rstats::Func::c(sv_r, sv_x2_length));
+      }
+
+      Rstats::Vector* x3_elements
+        = (*func)(Rstats::Func::get_vector(sv_r, sv_x1), Rstats::Func::get_vector(sv_r, sv_x2));
+      
+      SV* sv_x3 = Rstats::Func::new_null(sv_r);
+      Rstats::Func::set_vector(sv_r, sv_x3, x3_elements);
+      
+      Rstats::Func::copy_attrs_to(sv_r, sv_x1, sv_x3);
+      
+      return sv_x3;
+    }
+
+    SV* c(SV* sv_r, SV* sv_elements) {
+      
+      if (SvOK(sv_elements) && !SvROK(sv_elements)) {
+        SV* sv_elements_tmp = sv_elements;
+        sv_elements = Rstats::pl_new_av_ref();
+        Rstats::pl_av_push(sv_elements, sv_elements_tmp);
+      }
+      
+      IV element_length = Rstats::pl_av_len(sv_elements);
+      // Check type and length
+      std::map<Rstats::Type::Enum, IV> type_h;
+      IV length = 0;
+      for (IV i = 0; i < element_length; i++) {
+        Rstats::Type::Enum type;
+        SV* sv_element = Rstats::pl_av_fetch(sv_elements, i);
+        if (sv_isobject(sv_element) && sv_derived_from(sv_element, "Rstats::Array")) {
+          length += Rstats::VectorFunc::get_length(Rstats::Func::get_vector(sv_r, sv_element));
+          type = Rstats::VectorFunc::get_type(Rstats::Func::get_vector(sv_r, sv_element));
+          type_h[type] = 1;
+        }
+        else {
+          if (SvOK(sv_element)) {
+            if (Rstats::Util::is_perl_number(sv_element)) {
+              type_h[Rstats::Type::DOUBLE] = 1;
+            }
+            else {
+              type_h[Rstats::Type::CHARACTER] = 1;
+            }
+          }
+          else {
+            type_h[Rstats::Type::LOGICAL] = 1;
+          }
+          length += 1;
+        }
+      }
+
+      // Decide type
+      Rstats::Vector* v2;
+      if (type_h[Rstats::Type::CHARACTER]) {
+        v2 = Rstats::VectorFunc::new_character(length);
+      }
+      else if (type_h[Rstats::Type::COMPLEX]) {
+        v2 = Rstats::VectorFunc::new_complex(length);
+      }
+      else if (type_h[Rstats::Type::DOUBLE]) {
+        v2 = Rstats::VectorFunc::new_double(length);
+      }
+      else if (type_h[Rstats::Type::INTEGER]) {
+        v2 = Rstats::VectorFunc::new_integer(length);
+      }
+      else {
+        v2 = Rstats::VectorFunc::new_logical(length);
+      }
+      
+      Rstats::Type::Enum type = Rstats::VectorFunc::get_type(v2);
+      
+      IV pos = 0;
+      for (IV i = 0; i < element_length; i++) {
+        SV* sv_element = Rstats::pl_av_fetch(sv_elements, i);
+        if (sv_derived_from(sv_element, "Rstats::Array")) {
+          
+          Rstats::Vector* v1;
+          if (sv_derived_from(sv_element, "Rstats::Array")) {
+            v1 = Rstats::Func::get_vector(sv_r, sv_element);
+          }
+          else {
+            v1 = Rstats::pl_to_c_obj<Rstats::Vector*>(sv_element);
+          }
+          
+          Rstats::Vector* v_tmp;
+          if (Rstats::VectorFunc::get_type(v1) == type) {
+            v_tmp = v1;
+          }
+          else {
+            if (type == Rstats::Type::CHARACTER) {
+              v_tmp = Rstats::VectorFunc::as_character(v1);
+            }
+            else if (type == Rstats::Type::COMPLEX) {
+              v_tmp = Rstats::VectorFunc::as_complex(v1);
+            }
+            else if (type == Rstats::Type::DOUBLE) {
+              v_tmp = Rstats::VectorFunc::as_double(v1);
+            }
+            else if (type == Rstats::Type::INTEGER) {
+              v_tmp = Rstats::VectorFunc::as_integer(v1);
+            }
+            else {
+              v_tmp = Rstats::VectorFunc::as_logical(v1);
+            }
+          }
+          
+          for (IV k = 0; k < Rstats::VectorFunc::get_length(v_tmp); k++) {
+            if (Rstats::VectorFunc::exists_na_position(v_tmp, k)) {
+              Rstats::VectorFunc::add_na_position(v2, pos);
+            }
+            else {
+              if (type == Rstats::Type::CHARACTER) {
+                Rstats::VectorFunc::set_character_value(v2, pos, Rstats::VectorFunc::get_character_value(v_tmp, k));
+              }
+              else if (type == Rstats::Type::COMPLEX) {
+                Rstats::VectorFunc::set_complex_value(v2, pos, Rstats::VectorFunc::get_complex_value(v_tmp, k));
+              }
+              else if (type == Rstats::Type::DOUBLE) {
+                Rstats::VectorFunc::set_double_value(v2, pos, Rstats::VectorFunc::get_double_value(v_tmp, k));
+              }
+              else if (type == Rstats::Type::INTEGER) {
+                Rstats::VectorFunc::set_integer_value(v2, pos, Rstats::VectorFunc::get_integer_value(v_tmp, k));
+              }
+              else {
+                Rstats::VectorFunc::set_integer_value(v2, pos, Rstats::VectorFunc::get_integer_value(v_tmp, k));
+              }
+            }
+            
+            pos++;
+          }
+          
+          if (v_tmp != v1) {
+            delete v_tmp;
+          }
+        }
+        else {
+          if (SvOK(sv_element)) {
+            if (type == Rstats::Type::CHARACTER) {
+              Rstats::VectorFunc::set_character_value(v2, pos, sv_element);
+            }
+            else if (type == Rstats::Type::COMPLEX) {
+              Rstats::VectorFunc::set_complex_value(v2, pos, std::complex<NV>(SvNV(sv_element), 0));
+            }
+            else if (type == Rstats::Type::DOUBLE) {
+              Rstats::VectorFunc::set_double_value(v2, pos, SvNV(sv_element));
+            }
+            else if (type == Rstats::Type::INTEGER) {
+              Rstats::VectorFunc::set_integer_value(v2, pos, SvIV(sv_element));
+            }
+            else {
+              Rstats::VectorFunc::set_integer_value(v2, pos, SvIV(sv_element));
+            }
+          }
+          else {
+            Rstats::VectorFunc::add_na_position(v2, pos);
+          }
+          pos++;
+        }
+      }
+      
+      // Array
+      SV* sv_x1 = Rstats::Func::new_array(sv_r);
+      Rstats::Func::set_vector(sv_r, sv_x1, v2);
+
+      return sv_x1;
+    }
+    
+    SV* array(SV* sv_r, SV* sv_x1) {
+      SV* sv_args_h = Rstats::pl_new_hv_ref();
+      Rstats::pl_hv_store(sv_args_h, "x", sv_x1);
+      return Rstats::Func::array_with_opt(sv_r, sv_args_h);
+    }
+    
+    SV* array(SV* sv_r, SV* sv_x1, SV* sv_dim) {
+      
+      SV* sv_args_h = Rstats::pl_new_hv_ref();
+      Rstats::pl_hv_store(sv_args_h, "x", sv_x1);
+      Rstats::pl_hv_store(sv_args_h, "dim", sv_dim);
+      return Rstats::Func::array_with_opt(sv_r, sv_args_h);
+    }
+    
+    SV* array_with_opt(SV* sv_r, SV* sv_args_h) {
+
+      SV* sv_x1 = Rstats::pl_hv_fetch(sv_args_h, "x");
+     
+      // Dimention
+      SV* sv_x_dim = Rstats::pl_hv_exists(sv_args_h, "dim")
+        ? Rstats::pl_hv_fetch(sv_args_h, "dim") : Rstats::Func::new_null(sv_r);
+      SV* sv_x1_length = Rstats::Func::length_value(sv_r, sv_x1);
+
+      
+      Rstats::Func::length_value(sv_r, sv_x_dim);
+      
+      if (!SvIV(Rstats::Func::length_value(sv_r, sv_x_dim))) {
+        sv_x_dim = Rstats::Func::new_integer(sv_r, sv_x1_length);
+      }
+      IV dim_product = 1;
+      IV x_dim_length = SvIV(Rstats::Func::length_value(sv_r, sv_x_dim));
+      for (IV i = 0; i < x_dim_length; i++) {
+        SV* sv_values = Rstats::Func::values(sv_r, sv_x_dim);
+        dim_product *= SvIV(Rstats::pl_av_fetch(sv_values, i));
+      }
+
+      
+      // Fix elements length
+      SV* sv_elements;
+      if (SvIV(sv_x1_length) == dim_product) {
+        sv_elements = Rstats::Func::decompose(sv_r, sv_x1);
+      }
+      else if (SvIV(sv_x1_length) > dim_product) {
+        SV* sv_elements_tmp = Rstats::Func::decompose(sv_r, sv_x1);
+        sv_elements = Rstats::pl_new_av_ref();
+        for (IV i = 0; i < dim_product; i++) {
+          Rstats::pl_av_push(sv_elements, Rstats::pl_av_fetch(sv_elements_tmp, i));
+        }
+      }
+      else if (SvIV(sv_x1_length) < dim_product) {
+        SV* sv_elements_tmp = Rstats::Func::decompose(sv_r, sv_x1);
+        IV elements_tmp_length = Rstats::pl_av_len(sv_elements_tmp);
+        IV repeat_count = (IV)(dim_product / elements_tmp_length) + 1;
+        SV* sv_elements_tmp2 = Rstats::pl_new_av_ref();
+        IV elements_tmp2_length = Rstats::pl_av_len(sv_elements_tmp2);
+        for (IV i = 0; i < repeat_count; i++) {
+          for (IV k = 0; k < elements_tmp_length; k++) {
+            Rstats::pl_av_push(sv_elements_tmp2, Rstats::pl_av_fetch(sv_elements_tmp, k));
+          }
+        }
+        sv_elements = Rstats::pl_new_av_ref();
+        for (IV i = 0; i < dim_product; i++) {
+          Rstats::pl_av_push(sv_elements, Rstats::pl_av_fetch(sv_elements_tmp2, i));
+        }
+      }
+      
+      SV* sv_x2 = Rstats::Func::c(sv_r, sv_elements);
+      Rstats::Func::dim(sv_r, sv_x2, sv_x_dim);
+      
+      return sv_x2;
+    }
+    
+    SV* upgrade_type(SV* sv_r, SV* sv_xs) {
+      // Check elements
+      std::map<Rstats::Type::Enum, IV> type_h;
+      
+      IV xs_length = Rstats::pl_av_len(sv_xs);
+      for (IV i = 0; i < xs_length; i++) {
+        SV* sv_x1 = Rstats::pl_av_fetch(sv_xs, i);
+        Rstats::Vector* x1 = Rstats::Func::get_vector(sv_r, sv_x1);
+        Rstats::Type::Enum type = Rstats::VectorFunc::get_type(x1);
+        
+        if (type == Rstats::Type::CHARACTER) {
+          type_h[Rstats::Type::CHARACTER] = 1;
+        }
+        else if (type == Rstats::Type::COMPLEX) {
+          type_h[Rstats::Type::COMPLEX] = 1;
+        }
+        else if (type == Rstats::Type::DOUBLE) {
+          type_h[Rstats::Type::DOUBLE] = 1;
+        }
+        else if (type == Rstats::Type::INTEGER) {
+          type_h[Rstats::Type::INTEGER] = 1;
+        }
+        else if (type == Rstats::Type::LOGICAL) {
+          type_h[Rstats::Type::LOGICAL] = 1;
+        }
+        else {
+          croak("Invalid type(Rstats::Func::upgrade_type()");
+        }
+      }
+
+      // Upgrade elements and type if type is different
+      SV* sv_new_xs = Rstats::pl_new_av_ref();;
+      IV type_length = type_h.size();
+
+      if (type_length > 1) {
+        SV* sv_to_type;
+        if (type_h.count(Rstats::Type::CHARACTER)) {
+          sv_to_type = Rstats::pl_new_sv_pv("character");
+        }
+        else if (type_h.count(Rstats::Type::COMPLEX)) {
+          sv_to_type = Rstats::pl_new_sv_pv("complex");
+        }
+        else if (type_h.count(Rstats::Type::DOUBLE)) {
+          sv_to_type = Rstats::pl_new_sv_pv("double");
+        }
+        else if (type_h.count(Rstats::Type::INTEGER)) {
+          sv_to_type = Rstats::pl_new_sv_pv("integer");
+        }
+        else if (type_h.count(Rstats::Type::LOGICAL)) {
+          sv_to_type = Rstats::pl_new_sv_pv("logical");
+        }
+        
+        for (IV i = 0; i < xs_length; i++) {
+          SV* sv_x = Rstats::pl_av_fetch(sv_xs, i);
+          Rstats::pl_av_push(sv_new_xs, Rstats::Func::as(sv_r, sv_to_type, sv_x));
+        }
+      }
+      else {
+        sv_new_xs = sv_xs;
+      }
+      
+      return sv_new_xs;
+    }
+    
+    SV* operate_unary(SV* sv_r, Rstats::Vector* (*func)(Rstats::Vector*), SV* sv_x1) {
+      
+      Rstats::Vector* x2_elements = (*func)(get_vector(sv_r, sv_x1));
+      SV* sv_x2 = Rstats::Func::new_null(sv_r);
+      set_vector(sv_r, sv_x2, x2_elements);
+      Rstats::Func::copy_attrs_to(sv_r, sv_x1, sv_x2);
+      
+      return sv_x2;
+    }
+    
     SV* is_matrix(SV* sv_r, SV* sv_x1) {
 
       bool is = sv_isobject(sv_x1)
@@ -63,6 +403,8 @@ namespace Rstats {
 
     SV* length_value(SV* sv_r, SV* sv_x1) {
       SV* sv_length;
+
+      Rstats::pl_hv_exists(sv_x1, "vector");
       if (Rstats::pl_hv_exists(sv_x1, "vector")) {
         Rstats::Vector* x1 = get_vector(sv_r, sv_x1);
         IV length = Rstats::VectorFunc::get_length(x1);
@@ -431,154 +773,8 @@ namespace Rstats {
       return sv_x1;
     }
 
-    SV* c(SV* sv_r, SV* sv_elements) {
-
-      IV element_length = Rstats::pl_av_len(sv_elements);
-      // Check type and length
-      std::map<Rstats::Type::Enum, IV> type_h;
-      IV length = 0;
-      for (IV i = 0; i < element_length; i++) {
-        Rstats::Type::Enum type;
-        SV* sv_element = Rstats::pl_av_fetch(sv_elements, i);
-        if (sv_isobject(sv_element) && sv_derived_from(sv_element, "Rstats::Array")) {
-          length += Rstats::VectorFunc::get_length(Rstats::Func::get_vector(sv_r, sv_element));
-          type = Rstats::VectorFunc::get_type(Rstats::Func::get_vector(sv_r, sv_element));
-          type_h[type] = 1;
-        }
-        else {
-          if (SvOK(sv_element)) {
-            if (Rstats::Util::is_perl_number(sv_element)) {
-              type_h[Rstats::Type::DOUBLE] = 1;
-            }
-            else {
-              type_h[Rstats::Type::CHARACTER] = 1;
-            }
-          }
-          else {
-            type_h[Rstats::Type::LOGICAL] = 1;
-          }
-          length += 1;
-        }
-      }
-
-      // Decide type
-      Rstats::Vector* v2;
-      if (type_h[Rstats::Type::CHARACTER]) {
-        v2 = Rstats::VectorFunc::new_character(length);
-      }
-      else if (type_h[Rstats::Type::COMPLEX]) {
-        v2 = Rstats::VectorFunc::new_complex(length);
-      }
-      else if (type_h[Rstats::Type::DOUBLE]) {
-        v2 = Rstats::VectorFunc::new_double(length);
-      }
-      else if (type_h[Rstats::Type::INTEGER]) {
-        v2 = Rstats::VectorFunc::new_integer(length);
-      }
-      else {
-        v2 = Rstats::VectorFunc::new_logical(length);
-      }
-      
-      Rstats::Type::Enum type = Rstats::VectorFunc::get_type(v2);
-      
-      IV pos = 0;
-      for (IV i = 0; i < element_length; i++) {
-        SV* sv_element = Rstats::pl_av_fetch(sv_elements, i);
-        if (sv_derived_from(sv_element, "Rstats::Array")) {
-          
-          Rstats::Vector* v1;
-          if (sv_derived_from(sv_element, "Rstats::Array")) {
-            v1 = Rstats::Func::get_vector(sv_r, sv_element);
-          }
-          else {
-            v1 = Rstats::pl_to_c_obj<Rstats::Vector*>(sv_element);
-          }
-          
-          Rstats::Vector* v_tmp;
-          if (Rstats::VectorFunc::get_type(v1) == type) {
-            v_tmp = v1;
-          }
-          else {
-            if (type == Rstats::Type::CHARACTER) {
-              v_tmp = Rstats::VectorFunc::as_character(v1);
-            }
-            else if (type == Rstats::Type::COMPLEX) {
-              v_tmp = Rstats::VectorFunc::as_complex(v1);
-            }
-            else if (type == Rstats::Type::DOUBLE) {
-              v_tmp = Rstats::VectorFunc::as_double(v1);
-            }
-            else if (type == Rstats::Type::INTEGER) {
-              v_tmp = Rstats::VectorFunc::as_integer(v1);
-            }
-            else {
-              v_tmp = Rstats::VectorFunc::as_logical(v1);
-            }
-          }
-          
-          for (IV k = 0; k < Rstats::VectorFunc::get_length(v_tmp); k++) {
-            if (Rstats::VectorFunc::exists_na_position(v_tmp, k)) {
-              Rstats::VectorFunc::add_na_position(v2, pos);
-            }
-            else {
-              if (type == Rstats::Type::CHARACTER) {
-                Rstats::VectorFunc::set_character_value(v2, pos, Rstats::VectorFunc::get_character_value(v_tmp, k));
-              }
-              else if (type == Rstats::Type::COMPLEX) {
-                Rstats::VectorFunc::set_complex_value(v2, pos, Rstats::VectorFunc::get_complex_value(v_tmp, k));
-              }
-              else if (type == Rstats::Type::DOUBLE) {
-                Rstats::VectorFunc::set_double_value(v2, pos, Rstats::VectorFunc::get_double_value(v_tmp, k));
-              }
-              else if (type == Rstats::Type::INTEGER) {
-                Rstats::VectorFunc::set_integer_value(v2, pos, Rstats::VectorFunc::get_integer_value(v_tmp, k));
-              }
-              else {
-                Rstats::VectorFunc::set_integer_value(v2, pos, Rstats::VectorFunc::get_integer_value(v_tmp, k));
-              }
-            }
-            
-            pos++;
-          }
-          
-          if (v_tmp != v1) {
-            delete v_tmp;
-          }
-        }
-        else {
-          if (SvOK(sv_element)) {
-            if (type == Rstats::Type::CHARACTER) {
-              Rstats::VectorFunc::set_character_value(v2, pos, sv_element);
-            }
-            else if (type == Rstats::Type::COMPLEX) {
-              Rstats::VectorFunc::set_complex_value(v2, pos, std::complex<NV>(SvNV(sv_element), 0));
-            }
-            else if (type == Rstats::Type::DOUBLE) {
-              Rstats::VectorFunc::set_double_value(v2, pos, SvNV(sv_element));
-            }
-            else if (type == Rstats::Type::INTEGER) {
-              Rstats::VectorFunc::set_integer_value(v2, pos, SvIV(sv_element));
-            }
-            else {
-              Rstats::VectorFunc::set_integer_value(v2, pos, SvIV(sv_element));
-            }
-          }
-          else {
-            Rstats::VectorFunc::add_na_position(v2, pos);
-          }
-          pos++;
-        }
-      }
-      
-      // Array
-      SV* sv_x1 = Rstats::Func::new_array(sv_r);
-      Rstats::Func::set_vector(sv_r, sv_x1, v2);
-
-      return sv_x1;
-    }
-
     SV* to_c(SV* sv_r, SV* sv_x) {
-
+      
       IV is_container = sv_isobject(sv_x) && sv_derived_from(sv_x, "Rstats::Object");
       
       SV* sv_x1;
@@ -1272,73 +1468,6 @@ namespace Rstats {
       return sv_new_opt;
     }
     
-    SV* array(SV* sv_r, SV* sv_x1) {
-      SV* sv_args_h = Rstats::pl_new_hv_ref();
-      Rstats::pl_hv_store(sv_args_h, "x", sv_x1);
-      return Rstats::Func::array_with_opt(sv_r, sv_args_h);
-    }
-    
-    SV* array(SV* sv_r, SV* sv_x1, SV* sv_dim) {
-      SV* sv_args_h = Rstats::pl_new_hv_ref();
-      Rstats::pl_hv_store(sv_args_h, "x", sv_x1);
-      Rstats::pl_hv_store(sv_args_h, "dim", sv_dim);
-      return Rstats::Func::array_with_opt(sv_r, sv_args_h);
-    }
-    
-    SV* array_with_opt(SV* sv_r, SV* sv_args_h) {
-
-      SV* sv_x1 = Rstats::pl_hv_fetch(sv_args_h, "x");
-     
-      // Dimention
-      SV* sv_x_dim = Rstats::pl_hv_exists(sv_args_h, "dim")
-        ? Rstats::pl_hv_fetch(sv_args_h, "dim") : Rstats::Func::new_null(sv_r);
-      SV* sv_x1_length = Rstats::Func::length_value(sv_r, sv_x1);
-      if (!SvIV(Rstats::Func::length_value(sv_r, sv_x_dim))) {
-        sv_x_dim = Rstats::Func::new_integer(sv_r, sv_x1_length);
-      }
-      IV dim_product = 1;
-      IV x_dim_length = SvIV(Rstats::Func::length_value(sv_r, sv_x_dim));
-      for (IV i = 0; i < x_dim_length; i++) {
-        SV* sv_values = Rstats::Func::values(sv_r, sv_x_dim);
-        dim_product *= SvIV(Rstats::pl_av_fetch(sv_values, i));
-      }
-
-      
-      // Fix elements length
-      SV* sv_elements;
-      if (SvIV(sv_x1_length) == dim_product) {
-        sv_elements = Rstats::Func::decompose(sv_r, sv_x1);
-      }
-      else if (SvIV(sv_x1_length) > dim_product) {
-        SV* sv_elements_tmp = Rstats::Func::decompose(sv_r, sv_x1);
-        sv_elements = Rstats::pl_new_av_ref();
-        for (IV i = 0; i < dim_product; i++) {
-          Rstats::pl_av_push(sv_elements, Rstats::pl_av_fetch(sv_elements_tmp, i));
-        }
-      }
-      else if (SvIV(sv_x1_length) < dim_product) {
-        SV* sv_elements_tmp = Rstats::Func::decompose(sv_r, sv_x1);
-        IV elements_tmp_length = Rstats::pl_av_len(sv_elements_tmp);
-        IV repeat_count = (IV)(dim_product / elements_tmp_length) + 1;
-        SV* sv_elements_tmp2 = Rstats::pl_new_av_ref();
-        IV elements_tmp2_length = Rstats::pl_av_len(sv_elements_tmp2);
-        for (IV i = 0; i < repeat_count; i++) {
-          for (IV k = 0; k < elements_tmp_length; k++) {
-            Rstats::pl_av_push(sv_elements_tmp2, Rstats::pl_av_fetch(sv_elements_tmp, k));
-          }
-        }
-        sv_elements = Rstats::pl_new_av_ref();
-        for (IV i = 0; i < dim_product; i++) {
-          Rstats::pl_av_push(sv_elements, Rstats::pl_av_fetch(sv_elements_tmp2, i));
-        }
-      }
-      
-      SV* sv_x2 = Rstats::Func::c(sv_r, sv_elements);
-      Rstats::Func::dim(sv_r, sv_x2, sv_x_dim);
-      
-      return sv_x2;
-    }
-
     SV* as_array(SV* sv_r, SV* sv_x1) {
       
       SV* sv_x2 = Rstats::Func::as_vector(sv_r, sv_x1);
