@@ -80,7 +80,8 @@ my @func_names = qw/
   atan
   atanh
   atan2
-  se
+  c_
+  C_
   charmatch
   chartr
   cbind
@@ -102,15 +103,16 @@ my @func_names = qw/
   expm1
   factor
   F
+  F_
   FALSE
   floor
   gl
   grep
   gsub
   head
+  i_
   ifelse
   interaction
-  is_element
   I
   Im
   Re
@@ -150,7 +152,6 @@ my @func_names = qw/
   rank
   rbind
   quantile
-  read_table
   rep
   replace
   rev
@@ -177,7 +178,7 @@ my @func_names = qw/
   tanh
   tolower
   toupper
-  T
+  T_
   TRUE
   transform
   trunc
@@ -186,35 +187,6 @@ my @func_names = qw/
   upper_tri
   var
   which
-  as_array
-  is_array
-  is_character
-  is_complex
-  is_finite
-  is_infinite
-  is_list
-  is_matrix
-  is_na
-  is_nan
-  is_null
-  is_numeric
-  is_double
-  is_integer
-  is_logical
-  is_vector
-  is_factor
-  is_ordered
-  is_data_frame
-  as_character
-  as_complex
-  as_integer
-  as_double
-  as_list
-  as_logical
-  as_matrix
-  as_numeric
-  as_vector
-  as
   labels
   levels
   names
@@ -227,24 +199,30 @@ my @func_names = qw/
   typeof
   pi
   complex
-  i
   array
   length
-  c
   clone
+  equal
+  not_equal
+  less_than
+  less_than_or_equal
+  more_than
+  more_than_or_equal
+  add
+  subtract
+  multiply
+  divide
+  pow
   new_character
   new_complex
   new_double
   new_integer
   new_logical
+  negation
   dim
   Inf
   NaN
   NA
-  TRUE
-  T
-  FALSE
-  F
   to_string
   get
   set
@@ -268,8 +246,39 @@ sub new {
   }
 
   no strict 'refs';
+  $self->helper('is.array' => \&Rstats::Func::is_array);
+  $self->helper('is.character' => \&Rstats::Func::is_character);
+  $self->helper('is.complex' => \&Rstats::Func::is_complex);
+  $self->helper('is.finite' => \&Rstats::Func::is_finite);
+  $self->helper('is.infinite' => \&Rstats::Func::is_infinite);
+  $self->helper('is.list' => \&Rstats::Func::is_list);
+  $self->helper('is.matrix' => \&Rstats::Func::is_matrix);
+  $self->helper('is.na' => \&Rstats::Func::is_na);
+  $self->helper('is.nan' => \&Rstats::Func::is_nan);
+  $self->helper('is.null' => \&Rstats::Func::is_null);
+  $self->helper('is.numeric' => \&Rstats::Func::is_numeric);
+  $self->helper('is.double' => \&Rstats::Func::is_double);
+  $self->helper('is.integer' => \&Rstats::Func::is_integer);
+  $self->helper('is.vector' => \&Rstats::Func::is_vector);
+  $self->helper('is.factor' => \&Rstats::Func::is_factor);
+  $self->helper('is.ordered' => \&Rstats::Func::is_ordered);
+  $self->helper('is.data_frame' => \&Rstats::Func::is_data_frame);
   $self->helper('is.logical' => \&Rstats::Func::is_logical);
-  
+  $self->helper('is.element' => \&Rstats::Func::is_element);
+
+  $self->helper('as.array' => \&Rstats::Func::as_array);
+  $self->helper('as.character' => \&Rstats::Func::as_character);
+  $self->helper('as.complex' => \&Rstats::Func::as_complex);
+  $self->helper('as.integer' => \&Rstats::Func::as_integer);
+  $self->helper('as.double' => \&Rstats::Func::as_double);
+  $self->helper('as.list' => \&Rstats::Func::as_list);
+  $self->helper('as.logical' => \&Rstats::Func::as_logical);
+  $self->helper('as.matrix' => \&Rstats::Func::as_matrix);
+  $self->helper('as.numeric' => \&Rstats::Func::as_numeric);
+  $self->helper('as.vector' => \&Rstats::Func::as_vector);
+
+  $self->helper('read.table' => \&Rstats::Func::read_table);
+
   return $self;
 }
 
@@ -318,7 +327,7 @@ Rstats::Class - Rstats Object-Oriented interface
   my $r = Rstats::Class->new;
   
   # Array
-  my $v1 = $r->c([1, 2, 3]);
-  my $v2 = $r->c([2, 3, 4]);
+  my $v1 = $r->c_(1, 2, 3);
+  my $v2 = $r->c_(2, 3, 4);
   my $v3 = $v1 + v2;
   print $v3;
