@@ -11,7 +11,6 @@ use Rstats::Array;
 use Rstats::List;
 use Rstats::DataFrame;
 use Rstats::Util;
-use Rstats::VectorFunc;
 use Text::UnicodeTable::Simple;
 
 use List::Util ();
@@ -960,7 +959,7 @@ sub kronecker {
   my $x1 = to_c($r, shift);
   my $x2 = to_c($r, shift);
   
-  ($x1, $x2) = Rstats::Func::upgrade_type($r, $x1, $x2) if $x1->type ne $x2->type;
+  ($x1, $x2) = @{Rstats::Func::upgrade_type($r, [$x1, $x2])} if $x1->type ne $x2->type;
   
   my $x1_dim = Rstats::Func::dim($r, $x1);
   my $x2_dim = Rstats::Func::dim($r, $x2);
@@ -1013,7 +1012,7 @@ sub outer {
   my $x1 = to_c($r, shift);
   my $x2 = to_c($r, shift);
   
-  ($x1, $x2) = Rstats::Func::upgrade_type($r, $x1, $x2) if $x1->type ne $x2->type;
+  ($x1, $x2) = @{Rstats::Func::upgrade_type($r, [$x1, $x2])} if $x1->type ne $x2->type;
   
   my $x1_dim = Rstats::Func::dim($r, $x1);
   my $x2_dim = Rstats::Func::dim($r, $x2);
@@ -1042,15 +1041,7 @@ sub outer {
   return $x3;
 }
 
-sub Mod {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::Mod, @_);
-}
 
-sub Arg {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::Arg, @_);
-}
 
 sub sub {
   my $r = shift;
@@ -1146,29 +1137,6 @@ sub grep {
   return Rstats::Func::new_double($r, @$x2_values);
 }
 
-sub se {
-  my $r = shift;
-  my $seq_str = shift;
-
-  my $by;
-  my $mode;
-  if ($seq_str =~ s/^(.+)\*//) {
-    $by = $1;
-  }
-  
-  my $from;
-  my $to;
-  if ($seq_str =~ /([^\:]+)(?:\:(.+))?/) {
-    $from = $1;
-    $to = $2;
-    $to = $from unless defined $to;
-  }
-  
-  my $vector = seq($r,{from => $from, to => $to, by => $by});
-  
-  return $vector;
-}
-
 sub C_ {
   my $r = shift;
   my $seq_str = shift;
@@ -1271,20 +1239,7 @@ sub charmatch {
   return Rstats::Func::new_double($r, @$x2_values);
 }
 
-sub Conj {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::Conj, @_);
-}
 
-sub Re {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::Re, @_);
-}
-
-sub Im {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::Im, @_);
-}
 
 sub nrow {
   my $r = shift;
@@ -1549,19 +1504,6 @@ sub match {
   return Rstats::Func::new_double($r, @matches);
 }
 
-sub abs {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::abs, @_);
-}
-
-sub acos {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::acos, @_);
-}
-sub acosh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::acosh, @_);
-}
 
 
 sub append {
@@ -1586,25 +1528,7 @@ sub append {
   return $x3;
 }
 
-sub asin {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::asin, @_);
-}
 
-sub asinh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::asinh, @_);
-}
-
-sub atan {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::atan, @_);
-}
-
-sub atanh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::atanh, @_);
-}
 
 sub cbind {
   my $r = shift;
@@ -1728,20 +1652,9 @@ sub colSums {
   }
 }
 
-sub cos {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::cos, @_);
-}
 
-sub atan2 {
-  my $r = shift;
-  return operate_binary($r, \&Rstats::VectorFunc::atan2, @_);
-}
 
-sub cosh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::cosh, @_);
-}
+
 
 sub cummax {
   my $r = shift;
@@ -1804,15 +1717,7 @@ sub cummin {
   return Rstats::Func::c_($r, @x2_elements);
 }
 
-sub cumsum {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::cumsum, @_);
-}
 
-sub cumprod {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::cumprod, @_);
-}
 
 sub args_array {
   my $r = shift;
@@ -1894,15 +1799,6 @@ sub complex {
   return Rstats::Func::c_($r, @$x2_elements);
 }
 
-sub exp {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::exp, @_);
-}
-
-sub expm1 {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::expm1, @_);
-}
 
 sub floor {
   my $r = shift;
@@ -1952,14 +1848,6 @@ sub head {
   }
 }
 
-sub i {
-  my $r = shift;
-  
-  my $i = Rstats::Func::new_complex($r, {re => 0, im => 1});
-  
-  return Rstats::Func::c_($r, $i);
-}
-
 sub i_ {
   my $r = shift;
   
@@ -1989,25 +1877,7 @@ sub ifelse {
   return Rstats::Func::array($r, c_($r, @x2_values));
 }
 
-sub log {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::log, @_);
-}
 
-sub logb {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::logb, @_);
-}
-
-sub log2 {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::log2, @_);
-}
-
-sub log10 {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::log10, @_);
-}
 
 sub max {
   my $r = shift;
@@ -2209,10 +2079,7 @@ sub pmin {
   return Rstats::Func::c_($r, @mins);
 }
 
-sub prod {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::prod, @_);
-}
+
 
 sub range {
   my $r = shift;
@@ -2370,8 +2237,8 @@ sub rnorm {
     my ($rand1, $rand2) = (rand, rand);
     while ($rand1 == 0) { $rand1 = rand(); }
     
-    my $rnorm = ($sd * sqrt(-2 * CORE::log($rand1))
-      * sin(2 * Rstats::Util::pi() * $rand2))
+    my $rnorm = ($sd * CORE::sqrt(-2 * CORE::log($rand1))
+      * CORE::sin(2 * Rstats::Util::pi() * $rand2))
       + $mean;
     
     push @x1_elements, $rnorm;
@@ -2485,15 +2352,6 @@ sub sequence {
   return Rstats::Func::c_($r, @x2_values);
 }
 
-sub sinh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::sinh, @_);
-}
-
-sub sqrt {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::sqrt, @_);
-}
 
 sub tail {
   my $r = shift;
@@ -2515,35 +2373,6 @@ sub tail {
   return $x2;
 }
 
-sub tan {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::tan, @_);
-}
-
-sub sin {
-  my $r = shift;
-  operate_unary($r, \&Rstats::VectorFunc::sin, @_);
-}
-
-sub operate_unary {
-  my $r = shift;
-  
-  my $func = shift;
-  my $x1 = to_c($r, shift);
-  
-  my $x2_elements = $func->($x1->vector);
-  my $x2 = Rstats::Func::NULL($r);
-  $x2->vector($x2_elements);
-  Rstats::Func::copy_attrs_to($r, $x1, $x2);
-  
-  return $x2;
-}
-
-sub tanh {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::tanh, @_);
-}
-
 sub trunc {
   my $r = shift;
   
@@ -2768,10 +2597,7 @@ sub row {
   return Rstats::Func::array($r, Rstats::Func::c_($r, @values), Rstats::Func::c_($r, $nrow, $ncol));
 }
 
-sub sum {
-  my $r = shift;
-  return operate_unary($r, \&Rstats::VectorFunc::sum, @_);
-}
+
 
 sub ncol {
   my $r = shift;
@@ -2878,124 +2704,6 @@ sub numeric {
   return Rstats::Func::c_($r, (0) x $num);
 }
 
-sub upgrade_type {
-  my $r = shift;
-  
-  my (@xs) = @_;
-  
-  # Check elements
-  my $type_h = {};
-  for my $x1 (@xs) {
-    my $type = $x1->type || '';
-    if ($type eq 'character') {
-      $type_h->{character}++;
-    }
-    elsif ($type eq 'complex') {
-      $type_h->{complex}++;
-    }
-    elsif ($type eq 'double') {
-      $type_h->{double}++;
-    }
-    elsif ($type eq 'integer') {
-      $type_h->{integer}++;
-    }
-    elsif ($type eq 'logical') {
-      $type_h->{logical}++;
-    }
-    else {
-      Carp::croak "Invalid type";
-    }
-  }
-
-  # Upgrade elements and type if type is different
-  my @types = keys %$type_h;
-  if (@types > 1) {
-    my $to_type;
-    if ($type_h->{character}) {
-      $to_type = 'character';
-    }
-    elsif ($type_h->{complex}) {
-      $to_type = 'complex';
-    }
-    elsif ($type_h->{double}) {
-      $to_type = 'double';
-    }
-    elsif ($type_h->{integer}) {
-      $to_type = 'integer';
-    }
-    elsif ($type_h->{logical}) {
-      $to_type = 'logical';
-    }
-    for my $x (@xs) {
-      $x = Rstats::Func::as($r, $to_type, $x);
-    }
-  }
-  
-  return @xs;
-}
-
-sub add {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::add, @_);
-}
-sub subtract {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::subtract, @_);
-}
-sub multiply {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::multiply, @_);
-}
-sub divide {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::divide, @_);
-}
-sub remainder {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::remainder, @_);
-}
-sub pow {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::pow, @_);
-}
-sub less_than {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::less_than, @_);
-}
-sub less_than_or_equal {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::less_than_or_equal, @_);
-}
-sub more_than {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::more_than, @_);
-}
-sub more_than_or_equal {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::more_than_or_equal, @_);
-}
-sub equal {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::equal, @_);
-}
-sub not_equal {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::not_equal, @_);
-}
-sub and {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::and, @_);
-}
-sub or {
-  my $r = shift;
-  operate_binary($r, \&Rstats::VectorFunc::or, @_);
-}
-
-sub negation {
-  my $r = shift;
-  operate_unary($r, \&Rstats::VectorFunc::negation, @_);
-}
-
 sub _fix_pos {
   my $r = shift;
   
@@ -3021,45 +2729,6 @@ sub _fix_pos {
   return ($x1, $x2);
 }
 
-sub operate_binary {
-  my $r = shift;
-  
-  my ($func, $x1, $x2) = @_;
-  
-  $x1 = to_c($r, $x1);
-  $x2 = to_c($r, $x2);
-  
-  # Upgrade mode if type is different
-  ($x1, $x2) = Rstats::Func::upgrade_type($r, $x1, $x2)
-    if $x1->type ne $x2->type;
-  
-  # Upgrade length if length is defferent
-  my $x1_length = Rstats::Func::length_value($r, $x1);
-  my $x2_length = Rstats::Func::length_value($r, $x2);
-  my $length;
-  if ($x1_length > $x2_length) {
-    $x2 = Rstats::Func::array($r, $x2, $x1_length);
-    $length = $x1_length;
-  }
-  elsif ($x1_length < $x2_length) {
-    $x1 = Rstats::Func::array($r, $x1, $x2_length);
-    $length = $x2_length;
-  }
-  else {
-    $length = $x1_length;
-  }
-  
-  no strict 'refs';
-  my $x3;
-  my $x3_elements = $func->($x1->vector, $x2->vector);
-  $x3 = Rstats::Func::NULL($r);
-  $x3->vector($x3_elements);
-  
-  Rstats::Func::copy_attrs_to($r, $x1, $x3);
-
-  return $x3;
-}
-
 sub bool {
   my $r = shift;
   
@@ -4073,7 +3742,7 @@ sub set_array {
     # Upgrade mode if type is different
     if ($x1->type ne $x2->type) {
       my $x1_tmp;
-      ($x1_tmp, $x2) = Rstats::Func::upgrade_type($r, $x1, $x2);
+      ($x1_tmp, $x2) = @{Rstats::Func::upgrade_type($r, [$x1, $x2])};
       Rstats::Func::copy_attrs_to($r, $x1_tmp, $x1);
       $x1->vector($x1_tmp->vector);
     }
@@ -4114,7 +3783,7 @@ sub value {
   my $x1 = shift;
   
   my $e1;
-  my $dim_values = $x1->dim_as_array->values;
+  my $dim_values = Rstats::Func::values($r, $x1->dim_as_array);
   my $x1_elements = Rstats::Func::decompose($r, $x1);
   if (@_) {
     if (@$dim_values == 1) {
@@ -4132,7 +3801,7 @@ sub value {
     $e1 = $x1_elements->[0];
   }
   
-  return defined $e1 ? Rstats::VectorFunc::value($e1->vector) : undef;
+  return defined $e1 ? Rstats::Func::first_value($r, $e1) : undef;
 }
 
 1;
